# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/ratelimit/v3/rate_limit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.ratelimit.v3 import rls_pb2 as envoy_dot_config_dot_ratelimit_dot_v3_dot_rls__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/ratelimit/v3/rate_limit.proto',
  package='envoy.extensions.filters.http.ratelimit.v3',
  syntax='proto3',
  serialized_options=b'\n8io.envoyproxy.envoy.extensions.filters.http.ratelimit.v3B\016RateLimitProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n;envoy/extensions/filters/http/ratelimit/v3/rate_limit.proto\x12*envoy.extensions.filters.http.ratelimit.v3\x1a#envoy/config/ratelimit/v3/rls.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xe5\x04\n\tRateLimit\x12\x17\n\x06\x64omain\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x05stage\x18\x02 \x01(\rB\x07\xfa\x42\x04*\x02\x18\n\x12\x37\n\x0crequest_type\x18\x03 \x01(\tB!\xfa\x42\x1er\x1cR\x08internalR\x08\x65xternalR\x04\x62othR\x00\x12*\n\x07timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x19\n\x11\x66\x61ilure_mode_deny\x18\x05 \x01(\x08\x12*\n\"rate_limited_as_resource_exhausted\x18\x06 \x01(\x08\x12W\n\x12rate_limit_service\x18\x07 \x01(\x0b\x32\x31.envoy.config.ratelimit.v3.RateLimitServiceConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x7f\n\x1a\x65nable_x_ratelimit_headers\x18\x08 \x01(\x0e\x32Q.envoy.extensions.filters.http.ratelimit.v3.RateLimit.XRateLimitHeadersRFCVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12*\n\"disable_x_envoy_ratelimited_header\x18\t \x01(\x08\"<\n\x1bXRateLimitHeadersRFCVersion\x12\x07\n\x03OFF\x10\x00\x12\x14\n\x10\x44RAFT_VERSION_03\x10\x01:7\x9a\xc5\x88\x1e\x32\n0envoy.config.filter.http.rate_limit.v2.RateLimit\"\xc6\x01\n\x11RateLimitPerRoute\x12s\n\x0evh_rate_limits\x18\x01 \x01(\x0e\x32Q.envoy.extensions.filters.http.ratelimit.v3.RateLimitPerRoute.VhRateLimitsOptionsB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"<\n\x13VhRateLimitsOptions\x12\x0c\n\x08OVERRIDE\x10\x00\x12\x0b\n\x07INCLUDE\x10\x01\x12\n\n\x06IGNORE\x10\x02\x42T\n8io.envoyproxy.envoy.extensions.filters.http.ratelimit.v3B\x0eRateLimitProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_ratelimit_dot_v3_dot_rls__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_RATELIMIT_XRATELIMITHEADERSRFCVERSION = _descriptor.EnumDescriptor(
  name='XRateLimitHeadersRFCVersion',
  full_name='envoy.extensions.filters.http.ratelimit.v3.RateLimit.XRateLimitHeadersRFCVersion',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRAFT_VERSION_03', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=764,
  serialized_end=824,
)
_sym_db.RegisterEnumDescriptor(_RATELIMIT_XRATELIMITHEADERSRFCVERSION)

_RATELIMITPERROUTE_VHRATELIMITSOPTIONS = _descriptor.EnumDescriptor(
  name='VhRateLimitsOptions',
  full_name='envoy.extensions.filters.http.ratelimit.v3.RateLimitPerRoute.VhRateLimitsOptions',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OVERRIDE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INCLUDE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IGNORE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1022,
  serialized_end=1082,
)
_sym_db.RegisterEnumDescriptor(_RATELIMITPERROUTE_VHRATELIMITSOPTIONS)


_RATELIMIT = _descriptor.Descriptor(
  name='RateLimit',
  full_name='envoy.extensions.filters.http.ratelimit.v3.RateLimit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='domain', full_name='envoy.extensions.filters.http.ratelimit.v3.RateLimit.domain', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage', full_name='envoy.extensions.filters.http.ratelimit.v3.RateLimit.stage', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030\n', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_type', full_name='envoy.extensions.filters.http.ratelimit.v3.RateLimit.request_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\036r\034R\010internalR\010externalR\004bothR\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='envoy.extensions.filters.http.ratelimit.v3.RateLimit.timeout', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure_mode_deny', full_name='envoy.extensions.filters.http.ratelimit.v3.RateLimit.failure_mode_deny', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate_limited_as_resource_exhausted', full_name='envoy.extensions.filters.http.ratelimit.v3.RateLimit.rate_limited_as_resource_exhausted', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate_limit_service', full_name='envoy.extensions.filters.http.ratelimit.v3.RateLimit.rate_limit_service', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_x_ratelimit_headers', full_name='envoy.extensions.filters.http.ratelimit.v3.RateLimit.enable_x_ratelimit_headers', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_x_envoy_ratelimited_header', full_name='envoy.extensions.filters.http.ratelimit.v3.RateLimit.disable_x_envoy_ratelimited_header', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RATELIMIT_XRATELIMITHEADERSRFCVERSION,
  ],
  serialized_options=b'\232\305\210\0362\n0envoy.config.filter.http.rate_limit.v2.RateLimit',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=268,
  serialized_end=881,
)


_RATELIMITPERROUTE = _descriptor.Descriptor(
  name='RateLimitPerRoute',
  full_name='envoy.extensions.filters.http.ratelimit.v3.RateLimitPerRoute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vh_rate_limits', full_name='envoy.extensions.filters.http.ratelimit.v3.RateLimitPerRoute.vh_rate_limits', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RATELIMITPERROUTE_VHRATELIMITSOPTIONS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=884,
  serialized_end=1082,
)

_RATELIMIT.fields_by_name['timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_RATELIMIT.fields_by_name['rate_limit_service'].message_type = envoy_dot_config_dot_ratelimit_dot_v3_dot_rls__pb2._RATELIMITSERVICECONFIG
_RATELIMIT.fields_by_name['enable_x_ratelimit_headers'].enum_type = _RATELIMIT_XRATELIMITHEADERSRFCVERSION
_RATELIMIT_XRATELIMITHEADERSRFCVERSION.containing_type = _RATELIMIT
_RATELIMITPERROUTE.fields_by_name['vh_rate_limits'].enum_type = _RATELIMITPERROUTE_VHRATELIMITSOPTIONS
_RATELIMITPERROUTE_VHRATELIMITSOPTIONS.containing_type = _RATELIMITPERROUTE
DESCRIPTOR.message_types_by_name['RateLimit'] = _RATELIMIT
DESCRIPTOR.message_types_by_name['RateLimitPerRoute'] = _RATELIMITPERROUTE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RateLimit = _reflection.GeneratedProtocolMessageType('RateLimit', (_message.Message,), {
  'DESCRIPTOR' : _RATELIMIT,
  '__module__' : 'envoy.extensions.filters.http.ratelimit.v3.rate_limit_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ratelimit.v3.RateLimit)
  })
_sym_db.RegisterMessage(RateLimit)

RateLimitPerRoute = _reflection.GeneratedProtocolMessageType('RateLimitPerRoute', (_message.Message,), {
  'DESCRIPTOR' : _RATELIMITPERROUTE,
  '__module__' : 'envoy.extensions.filters.http.ratelimit.v3.rate_limit_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ratelimit.v3.RateLimitPerRoute)
  })
_sym_db.RegisterMessage(RateLimitPerRoute)


DESCRIPTOR._options = None
_RATELIMIT.fields_by_name['domain']._options = None
_RATELIMIT.fields_by_name['stage']._options = None
_RATELIMIT.fields_by_name['request_type']._options = None
_RATELIMIT.fields_by_name['rate_limit_service']._options = None
_RATELIMIT.fields_by_name['enable_x_ratelimit_headers']._options = None
_RATELIMIT._options = None
_RATELIMITPERROUTE.fields_by_name['vh_rate_limits']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/ratelimit/v3/rls.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.extensions.common.ratelimit.v3 import ratelimit_pb2 as envoy_dot_extensions_dot_common_dot_ratelimit_dot_v3_dot_ratelimit__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/ratelimit/v3/rls.proto',
  package='envoy.service.ratelimit.v3',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.service.ratelimit.v3B\010RlsProtoP\001\210\001\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$envoy/service/ratelimit/v3/rls.proto\x12\x1a\x65nvoy.service.ratelimit.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x34\x65nvoy/extensions/common/ratelimit/v3/ratelimit.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xbb\x01\n\x10RateLimitRequest\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12N\n\x0b\x64\x65scriptors\x18\x02 \x03(\x0b\x32\x39.envoy.extensions.common.ratelimit.v3.RateLimitDescriptor\x12\x13\n\x0bhits_addend\x18\x03 \x01(\r:2\x9a\xc5\x88\x1e-\n+envoy.service.ratelimit.v2.RateLimitRequest\"\x9e\x08\n\x11RateLimitResponse\x12H\n\x0coverall_code\x18\x01 \x01(\x0e\x32\x32.envoy.service.ratelimit.v3.RateLimitResponse.Code\x12P\n\x08statuses\x18\x02 \x03(\x0b\x32>.envoy.service.ratelimit.v3.RateLimitResponse.DescriptorStatus\x12\x42\n\x17response_headers_to_add\x18\x03 \x03(\x0b\x32!.envoy.config.core.v3.HeaderValue\x12\x41\n\x16request_headers_to_add\x18\x04 \x03(\x0b\x32!.envoy.config.core.v3.HeaderValue\x12\x10\n\x08raw_body\x18\x05 \x01(\x0c\x12\x31\n\x10\x64ynamic_metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x1a\xff\x01\n\tRateLimit\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x19\n\x11requests_per_unit\x18\x01 \x01(\r\x12J\n\x04unit\x18\x02 \x01(\x0e\x32<.envoy.service.ratelimit.v3.RateLimitResponse.RateLimit.Unit\">\n\x04Unit\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06SECOND\x10\x01\x12\n\n\x06MINUTE\x10\x02\x12\x08\n\x04HOUR\x10\x03\x12\x07\n\x03\x44\x41Y\x10\x04:=\x9a\xc5\x88\x1e\x38\n6envoy.service.ratelimit.v2.RateLimitResponse.RateLimit\x1a\xbc\x02\n\x10\x44\x65scriptorStatus\x12@\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x32.envoy.service.ratelimit.v3.RateLimitResponse.Code\x12N\n\rcurrent_limit\x18\x02 \x01(\x0b\x32\x37.envoy.service.ratelimit.v3.RateLimitResponse.RateLimit\x12\x17\n\x0flimit_remaining\x18\x03 \x01(\r\x12\x37\n\x14\x64uration_until_reset\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration:D\x9a\xc5\x88\x1e?\n=envoy.service.ratelimit.v2.RateLimitResponse.DescriptorStatus\"+\n\x04\x43ode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0e\n\nOVER_LIMIT\x10\x02:3\x9a\xc5\x88\x1e.\n,envoy.service.ratelimit.v2.RateLimitResponse2\x84\x01\n\x10RateLimitService\x12p\n\x0fShouldRateLimit\x12,.envoy.service.ratelimit.v3.RateLimitRequest\x1a-.envoy.service.ratelimit.v3.RateLimitResponse\"\x00\x42\x41\n(io.envoyproxy.envoy.service.ratelimit.v3B\x08RlsProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_extensions_dot_common_dot_ratelimit_dot_v3_dot_ratelimit__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])



_RATELIMITRESPONSE_RATELIMIT_UNIT = _descriptor.EnumDescriptor(
  name='Unit',
  full_name='envoy.service.ratelimit.v3.RateLimitResponse.RateLimit.Unit',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECOND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MINUTE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOUR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DAY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=986,
  serialized_end=1048,
)
_sym_db.RegisterEnumDescriptor(_RATELIMITRESPONSE_RATELIMIT_UNIT)

_RATELIMITRESPONSE_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='envoy.service.ratelimit.v3.RateLimitResponse.Code',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OVER_LIMIT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1432,
  serialized_end=1475,
)
_sym_db.RegisterEnumDescriptor(_RATELIMITRESPONSE_CODE)


_RATELIMITREQUEST = _descriptor.Descriptor(
  name='RateLimitRequest',
  full_name='envoy.service.ratelimit.v3.RateLimitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='domain', full_name='envoy.service.ratelimit.v3.RateLimitRequest.domain', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='descriptors', full_name='envoy.service.ratelimit.v3.RateLimitRequest.descriptors', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hits_addend', full_name='envoy.service.ratelimit.v3.RateLimitRequest.hits_addend', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036-\n+envoy.service.ratelimit.v2.RateLimitRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=471,
)


_RATELIMITRESPONSE_RATELIMIT = _descriptor.Descriptor(
  name='RateLimit',
  full_name='envoy.service.ratelimit.v3.RateLimitResponse.RateLimit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.service.ratelimit.v3.RateLimitResponse.RateLimit.name', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requests_per_unit', full_name='envoy.service.ratelimit.v3.RateLimitResponse.RateLimit.requests_per_unit', index=1,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='envoy.service.ratelimit.v3.RateLimitResponse.RateLimit.unit', index=2,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RATELIMITRESPONSE_RATELIMIT_UNIT,
  ],
  serialized_options=b'\232\305\210\0368\n6envoy.service.ratelimit.v2.RateLimitResponse.RateLimit',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=856,
  serialized_end=1111,
)

_RATELIMITRESPONSE_DESCRIPTORSTATUS = _descriptor.Descriptor(
  name='DescriptorStatus',
  full_name='envoy.service.ratelimit.v3.RateLimitResponse.DescriptorStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='envoy.service.ratelimit.v3.RateLimitResponse.DescriptorStatus.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_limit', full_name='envoy.service.ratelimit.v3.RateLimitResponse.DescriptorStatus.current_limit', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit_remaining', full_name='envoy.service.ratelimit.v3.RateLimitResponse.DescriptorStatus.limit_remaining', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration_until_reset', full_name='envoy.service.ratelimit.v3.RateLimitResponse.DescriptorStatus.duration_until_reset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036?\n=envoy.service.ratelimit.v2.RateLimitResponse.DescriptorStatus',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1114,
  serialized_end=1430,
)

_RATELIMITRESPONSE = _descriptor.Descriptor(
  name='RateLimitResponse',
  full_name='envoy.service.ratelimit.v3.RateLimitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='overall_code', full_name='envoy.service.ratelimit.v3.RateLimitResponse.overall_code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statuses', full_name='envoy.service.ratelimit.v3.RateLimitResponse.statuses', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_headers_to_add', full_name='envoy.service.ratelimit.v3.RateLimitResponse.response_headers_to_add', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers_to_add', full_name='envoy.service.ratelimit.v3.RateLimitResponse.request_headers_to_add', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_body', full_name='envoy.service.ratelimit.v3.RateLimitResponse.raw_body', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_metadata', full_name='envoy.service.ratelimit.v3.RateLimitResponse.dynamic_metadata', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RATELIMITRESPONSE_RATELIMIT, _RATELIMITRESPONSE_DESCRIPTORSTATUS, ],
  enum_types=[
    _RATELIMITRESPONSE_CODE,
  ],
  serialized_options=b'\232\305\210\036.\n,envoy.service.ratelimit.v2.RateLimitResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=474,
  serialized_end=1528,
)

_RATELIMITREQUEST.fields_by_name['descriptors'].message_type = envoy_dot_extensions_dot_common_dot_ratelimit_dot_v3_dot_ratelimit__pb2._RATELIMITDESCRIPTOR
_RATELIMITRESPONSE_RATELIMIT.fields_by_name['unit'].enum_type = _RATELIMITRESPONSE_RATELIMIT_UNIT
_RATELIMITRESPONSE_RATELIMIT.containing_type = _RATELIMITRESPONSE
_RATELIMITRESPONSE_RATELIMIT_UNIT.containing_type = _RATELIMITRESPONSE_RATELIMIT
_RATELIMITRESPONSE_DESCRIPTORSTATUS.fields_by_name['code'].enum_type = _RATELIMITRESPONSE_CODE
_RATELIMITRESPONSE_DESCRIPTORSTATUS.fields_by_name['current_limit'].message_type = _RATELIMITRESPONSE_RATELIMIT
_RATELIMITRESPONSE_DESCRIPTORSTATUS.fields_by_name['duration_until_reset'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_RATELIMITRESPONSE_DESCRIPTORSTATUS.containing_type = _RATELIMITRESPONSE
_RATELIMITRESPONSE.fields_by_name['overall_code'].enum_type = _RATELIMITRESPONSE_CODE
_RATELIMITRESPONSE.fields_by_name['statuses'].message_type = _RATELIMITRESPONSE_DESCRIPTORSTATUS
_RATELIMITRESPONSE.fields_by_name['response_headers_to_add'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._HEADERVALUE
_RATELIMITRESPONSE.fields_by_name['request_headers_to_add'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._HEADERVALUE
_RATELIMITRESPONSE.fields_by_name['dynamic_metadata'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_RATELIMITRESPONSE_CODE.containing_type = _RATELIMITRESPONSE
DESCRIPTOR.message_types_by_name['RateLimitRequest'] = _RATELIMITREQUEST
DESCRIPTOR.message_types_by_name['RateLimitResponse'] = _RATELIMITRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RateLimitRequest = _reflection.GeneratedProtocolMessageType('RateLimitRequest', (_message.Message,), {
  'DESCRIPTOR' : _RATELIMITREQUEST,
  '__module__' : 'envoy.service.ratelimit.v3.rls_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ratelimit.v3.RateLimitRequest)
  })
_sym_db.RegisterMessage(RateLimitRequest)

RateLimitResponse = _reflection.GeneratedProtocolMessageType('RateLimitResponse', (_message.Message,), {

  'RateLimit' : _reflection.GeneratedProtocolMessageType('RateLimit', (_message.Message,), {
    'DESCRIPTOR' : _RATELIMITRESPONSE_RATELIMIT,
    '__module__' : 'envoy.service.ratelimit.v3.rls_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.ratelimit.v3.RateLimitResponse.RateLimit)
    })
  ,

  'DescriptorStatus' : _reflection.GeneratedProtocolMessageType('DescriptorStatus', (_message.Message,), {
    'DESCRIPTOR' : _RATELIMITRESPONSE_DESCRIPTORSTATUS,
    '__module__' : 'envoy.service.ratelimit.v3.rls_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.ratelimit.v3.RateLimitResponse.DescriptorStatus)
    })
  ,
  'DESCRIPTOR' : _RATELIMITRESPONSE,
  '__module__' : 'envoy.service.ratelimit.v3.rls_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ratelimit.v3.RateLimitResponse)
  })
_sym_db.RegisterMessage(RateLimitResponse)
_sym_db.RegisterMessage(RateLimitResponse.RateLimit)
_sym_db.RegisterMessage(RateLimitResponse.DescriptorStatus)


DESCRIPTOR._options = None
_RATELIMITREQUEST._options = None
_RATELIMITRESPONSE_RATELIMIT._options = None
_RATELIMITRESPONSE_DESCRIPTORSTATUS._options = None
_RATELIMITRESPONSE._options = None

_RATELIMITSERVICE = _descriptor.ServiceDescriptor(
  name='RateLimitService',
  full_name='envoy.service.ratelimit.v3.RateLimitService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1531,
  serialized_end=1663,
  methods=[
  _descriptor.MethodDescriptor(
    name='ShouldRateLimit',
    full_name='envoy.service.ratelimit.v3.RateLimitService.ShouldRateLimit',
    index=0,
    containing_service=None,
    input_type=_RATELIMITREQUEST,
    output_type=_RATELIMITRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RATELIMITSERVICE)

DESCRIPTOR.services_by_name['RateLimitService'] = _RATELIMITSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/auth/secret.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.auth import common_pb2 as envoy_dot_api_dot_v2_dot_auth_dot_common__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import config_source_pb2 as envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/auth/secret.proto',
  package='envoy.api.v2.auth',
  syntax='proto3',
  serialized_options=b'\n\037io.envoyproxy.envoy.api.v2.authB\013SecretProtoP\001\362\230\376\217\005+\022)envoy.extensions.transport_sockets.tls.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65nvoy/api/v2/auth/secret.proto\x12\x11\x65nvoy.api.v2.auth\x1a\x1e\x65nvoy/api/v2/auth/common.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a%envoy/api/v2/core/config_source.proto\x1a\x1eudpa/annotations/migrate.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\"F\n\rGenericSecret\x12\x35\n\x06secret\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\"T\n\x0fSdsSecretConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x33\n\nsds_config\x18\x02 \x01(\x0b\x32\x1f.envoy.api.v2.core.ConfigSource\"\xaf\x02\n\x06Secret\x12\x0c\n\x04name\x18\x01 \x01(\t\x12<\n\x0ftls_certificate\x18\x02 \x01(\x0b\x32!.envoy.api.v2.auth.TlsCertificateH\x00\x12\x46\n\x13session_ticket_keys\x18\x03 \x01(\x0b\x32\'.envoy.api.v2.auth.TlsSessionTicketKeysH\x00\x12M\n\x12validation_context\x18\x04 \x01(\x0b\x32/.envoy.api.v2.auth.CertificateValidationContextH\x00\x12:\n\x0egeneric_secret\x18\x05 \x01(\x0b\x32 .envoy.api.v2.auth.GenericSecretH\x00\x42\x06\n\x04typeBi\n\x1fio.envoyproxy.envoy.api.v2.authB\x0bSecretProtoP\x01\xf2\x98\xfe\x8f\x05+\x12)envoy.extensions.transport_sockets.tls.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_auth_dot_common__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_sensitive__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_GENERICSECRET = _descriptor.Descriptor(
  name='GenericSecret',
  full_name='envoy.api.v2.auth.GenericSecret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='secret', full_name='envoy.api.v2.auth.GenericSecret.secret', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=321,
)


_SDSSECRETCONFIG = _descriptor.Descriptor(
  name='SdsSecretConfig',
  full_name='envoy.api.v2.auth.SdsSecretConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.api.v2.auth.SdsSecretConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sds_config', full_name='envoy.api.v2.auth.SdsSecretConfig.sds_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=323,
  serialized_end=407,
)


_SECRET = _descriptor.Descriptor(
  name='Secret',
  full_name='envoy.api.v2.auth.Secret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.api.v2.auth.Secret.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_certificate', full_name='envoy.api.v2.auth.Secret.tls_certificate', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_ticket_keys', full_name='envoy.api.v2.auth.Secret.session_ticket_keys', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validation_context', full_name='envoy.api.v2.auth.Secret.validation_context', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generic_secret', full_name='envoy.api.v2.auth.Secret.generic_secret', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='envoy.api.v2.auth.Secret.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=410,
  serialized_end=713,
)

_GENERICSECRET.fields_by_name['secret'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_SDSSECRETCONFIG.fields_by_name['sds_config'].message_type = envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2._CONFIGSOURCE
_SECRET.fields_by_name['tls_certificate'].message_type = envoy_dot_api_dot_v2_dot_auth_dot_common__pb2._TLSCERTIFICATE
_SECRET.fields_by_name['session_ticket_keys'].message_type = envoy_dot_api_dot_v2_dot_auth_dot_common__pb2._TLSSESSIONTICKETKEYS
_SECRET.fields_by_name['validation_context'].message_type = envoy_dot_api_dot_v2_dot_auth_dot_common__pb2._CERTIFICATEVALIDATIONCONTEXT
_SECRET.fields_by_name['generic_secret'].message_type = _GENERICSECRET
_SECRET.oneofs_by_name['type'].fields.append(
  _SECRET.fields_by_name['tls_certificate'])
_SECRET.fields_by_name['tls_certificate'].containing_oneof = _SECRET.oneofs_by_name['type']
_SECRET.oneofs_by_name['type'].fields.append(
  _SECRET.fields_by_name['session_ticket_keys'])
_SECRET.fields_by_name['session_ticket_keys'].containing_oneof = _SECRET.oneofs_by_name['type']
_SECRET.oneofs_by_name['type'].fields.append(
  _SECRET.fields_by_name['validation_context'])
_SECRET.fields_by_name['validation_context'].containing_oneof = _SECRET.oneofs_by_name['type']
_SECRET.oneofs_by_name['type'].fields.append(
  _SECRET.fields_by_name['generic_secret'])
_SECRET.fields_by_name['generic_secret'].containing_oneof = _SECRET.oneofs_by_name['type']
DESCRIPTOR.message_types_by_name['GenericSecret'] = _GENERICSECRET
DESCRIPTOR.message_types_by_name['SdsSecretConfig'] = _SDSSECRETCONFIG
DESCRIPTOR.message_types_by_name['Secret'] = _SECRET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GenericSecret = _reflection.GeneratedProtocolMessageType('GenericSecret', (_message.Message,), {
  'DESCRIPTOR' : _GENERICSECRET,
  '__module__' : 'envoy.api.v2.auth.secret_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.auth.GenericSecret)
  })
_sym_db.RegisterMessage(GenericSecret)

SdsSecretConfig = _reflection.GeneratedProtocolMessageType('SdsSecretConfig', (_message.Message,), {
  'DESCRIPTOR' : _SDSSECRETCONFIG,
  '__module__' : 'envoy.api.v2.auth.secret_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.auth.SdsSecretConfig)
  })
_sym_db.RegisterMessage(SdsSecretConfig)

Secret = _reflection.GeneratedProtocolMessageType('Secret', (_message.Message,), {
  'DESCRIPTOR' : _SECRET,
  '__module__' : 'envoy.api.v2.auth.secret_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.auth.Secret)
  })
_sym_db.RegisterMessage(Secret)


DESCRIPTOR._options = None
_GENERICSECRET.fields_by_name['secret']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/cluster/filter.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/cluster/filter.proto',
  package='envoy.api.v2.cluster',
  syntax='proto3',
  serialized_options=b'\n\"io.envoyproxy.envoy.api.v2.clusterB\013FilterProtoP\001\252\002\026Envoy.Api.V2.ClusterNS\352\002\026Envoy.Api.V2.ClusterNS\362\230\376\217\005\031\022\027envoy.config.cluster.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!envoy/api/v2/cluster/filter.proto\x12\x14\x65nvoy.api.v2.cluster\x1a\x19google/protobuf/any.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"K\n\x06\x46ilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12*\n\x0ctyped_config\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x8c\x01\n\"io.envoyproxy.envoy.api.v2.clusterB\x0b\x46ilterProtoP\x01\xaa\x02\x16\x45nvoy.Api.V2.ClusterNS\xea\x02\x16\x45nvoy.Api.V2.ClusterNS\xf2\x98\xfe\x8f\x05\x19\x12\x17\x65nvoy.config.cluster.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='envoy.api.v2.cluster.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.api.v2.cluster.Filter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.api.v2.cluster.Filter.typed_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=249,
)

_FILTER.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['Filter'] = _FILTER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Filter = _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
  'DESCRIPTOR' : _FILTER,
  '__module__' : 'envoy.api.v2.cluster.filter_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.cluster.Filter)
  })
_sym_db.RegisterMessage(Filter)


DESCRIPTOR._options = None
_FILTER.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/transport_sockets/tls/v3/cert.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.transport_sockets.tls.v3 import common_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_common__pb2
from envoy.extensions.transport_sockets.tls.v3 import secret_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_secret__pb2
from envoy.extensions.transport_sockets.tls.v3 import tls_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_tls__pb2

from envoy.extensions.transport_sockets.tls.v3.common_pb2 import *
from envoy.extensions.transport_sockets.tls.v3.secret_pb2 import *
from envoy.extensions.transport_sockets.tls.v3.tls_pb2 import *

DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/transport_sockets/tls/v3/cert.proto',
  package='envoy.extensions.transport_sockets.tls.v3',
  syntax='proto3',
  serialized_options=b'\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\tCertProtoP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4envoy/extensions/transport_sockets/tls/v3/cert.proto\x12)envoy.extensions.transport_sockets.tls.v3\x1a\x36\x65nvoy/extensions/transport_sockets/tls/v3/common.proto\x1a\x36\x65nvoy/extensions/transport_sockets/tls/v3/secret.proto\x1a\x33\x65nvoy/extensions/transport_sockets/tls/v3/tls.protoBF\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\tCertProtoP\x01P\x00P\x01P\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_common__pb2.DESCRIPTOR,envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_secret__pb2.DESCRIPTOR,envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_tls__pb2.DESCRIPTOR,],
  public_dependencies=[envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_common__pb2.DESCRIPTOR,envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_secret__pb2.DESCRIPTOR,envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_tls__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/listener.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import socket_option_pb2 as envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
from envoy.api.v2.listener import listener_components_pb2 as envoy_dot_api_dot_v2_dot_listener_dot_listener__components__pb2
from envoy.api.v2.listener import udp_listener_config_pb2 as envoy_dot_api_dot_v2_dot_listener_dot_udp__listener__config__pb2
from envoy.config.filter.accesslog.v2 import accesslog_pb2 as envoy_dot_config_dot_filter_dot_accesslog_dot_v2_dot_accesslog__pb2
from envoy.config.listener.v2 import api_listener_pb2 as envoy_dot_config_dot_listener_dot_v2_dot_api__listener__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/listener.proto',
  package='envoy.api.v2',
  syntax='proto3',
  serialized_options=b'\n\032io.envoyproxy.envoy.api.v2B\rListenerProtoP\001\362\230\376\217\005\032\022\030envoy.config.listener.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1b\x65nvoy/api/v2/listener.proto\x12\x0c\x65nvoy.api.v2\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a%envoy/api/v2/core/socket_option.proto\x1a/envoy/api/v2/listener/listener_components.proto\x1a/envoy/api/v2/listener/udp_listener_config.proto\x1a\x30\x65nvoy/config/filter/accesslog/v2/accesslog.proto\x1a+envoy/config/listener/v2/api_listener.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xaa\x0b\n\x08Listener\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x35\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x1a.envoy.api.v2.core.AddressB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x39\n\rfilter_chains\x18\x03 \x03(\x0b\x32\".envoy.api.v2.listener.FilterChain\x12\x38\n\x10use_original_dst\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x02\x18\x01\x12G\n!per_connection_buffer_limit_bytes\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12-\n\x08metadata\x18\x06 \x01(\x0b\x32\x1b.envoy.api.v2.core.Metadata\x12:\n\rdeprecated_v1\x18\x07 \x01(\x0b\x32#.envoy.api.v2.Listener.DeprecatedV1\x12\x34\n\ndrain_type\x18\x08 \x01(\x0e\x32 .envoy.api.v2.Listener.DrainType\x12?\n\x10listener_filters\x18\t \x03(\x0b\x32%.envoy.api.v2.listener.ListenerFilter\x12;\n\x18listener_filters_timeout\x18\x0f \x01(\x0b\x32\x19.google.protobuf.Duration\x12,\n$continue_on_listener_filters_timeout\x18\x11 \x01(\x08\x12/\n\x0btransparent\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x08\x66reebind\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x0esocket_options\x18\r \x03(\x0b\x32\x1f.envoy.api.v2.core.SocketOption\x12@\n\x1atcp_fast_open_queue_length\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12>\n\x11traffic_direction\x18\x10 \x01(\x0e\x32#.envoy.api.v2.core.TrafficDirection\x12\x45\n\x13udp_listener_config\x18\x12 \x01(\x0b\x32(.envoy.api.v2.listener.UdpListenerConfig\x12;\n\x0c\x61pi_listener\x18\x13 \x01(\x0b\x32%.envoy.config.listener.v2.ApiListener\x12Q\n\x19\x63onnection_balance_config\x18\x14 \x01(\x0b\x32..envoy.api.v2.Listener.ConnectionBalanceConfig\x12\x12\n\nreuse_port\x18\x15 \x01(\x08\x12?\n\naccess_log\x18\x16 \x03(\x0b\x32+.envoy.config.filter.accesslog.v2.AccessLog\x1a@\n\x0c\x44\x65precatedV1\x12\x30\n\x0c\x62ind_to_port\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\x94\x01\n\x17\x43onnectionBalanceConfig\x12T\n\rexact_balance\x18\x01 \x01(\x0b\x32;.envoy.api.v2.Listener.ConnectionBalanceConfig.ExactBalanceH\x00\x1a\x0e\n\x0c\x45xactBalanceB\x13\n\x0c\x62\x61lance_type\x12\x03\xf8\x42\x01\")\n\tDrainType\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0f\n\x0bMODIFY_ONLY\x10\x01J\x04\x08\x0e\x10\x0f\x42U\n\x1aio.envoyproxy.envoy.api.v2B\rListenerProtoP\x01\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.config.listener.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_address__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_listener_dot_listener__components__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_listener_dot_udp__listener__config__pb2.DESCRIPTOR,envoy_dot_config_dot_filter_dot_accesslog_dot_v2_dot_accesslog__pb2.DESCRIPTOR,envoy_dot_config_dot_listener_dot_v2_dot_api__listener__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_LISTENER_DRAINTYPE = _descriptor.EnumDescriptor(
  name='DrainType',
  full_name='envoy.api.v2.Listener.DrainType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MODIFY_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1896,
  serialized_end=1937,
)
_sym_db.RegisterEnumDescriptor(_LISTENER_DRAINTYPE)


_LISTENER_DEPRECATEDV1 = _descriptor.Descriptor(
  name='DeprecatedV1',
  full_name='envoy.api.v2.Listener.DeprecatedV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bind_to_port', full_name='envoy.api.v2.Listener.DeprecatedV1.bind_to_port', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1679,
  serialized_end=1743,
)

_LISTENER_CONNECTIONBALANCECONFIG_EXACTBALANCE = _descriptor.Descriptor(
  name='ExactBalance',
  full_name='envoy.api.v2.Listener.ConnectionBalanceConfig.ExactBalance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1859,
  serialized_end=1873,
)

_LISTENER_CONNECTIONBALANCECONFIG = _descriptor.Descriptor(
  name='ConnectionBalanceConfig',
  full_name='envoy.api.v2.Listener.ConnectionBalanceConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exact_balance', full_name='envoy.api.v2.Listener.ConnectionBalanceConfig.exact_balance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTENER_CONNECTIONBALANCECONFIG_EXACTBALANCE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='balance_type', full_name='envoy.api.v2.Listener.ConnectionBalanceConfig.balance_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1746,
  serialized_end=1894,
)

_LISTENER = _descriptor.Descriptor(
  name='Listener',
  full_name='envoy.api.v2.Listener',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.api.v2.Listener.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='envoy.api.v2.Listener.address', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_chains', full_name='envoy.api.v2.Listener.filter_chains', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_original_dst', full_name='envoy.api.v2.Listener.use_original_dst', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='per_connection_buffer_limit_bytes', full_name='envoy.api.v2.Listener.per_connection_buffer_limit_bytes', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='envoy.api.v2.Listener.metadata', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_v1', full_name='envoy.api.v2.Listener.deprecated_v1', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drain_type', full_name='envoy.api.v2.Listener.drain_type', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listener_filters', full_name='envoy.api.v2.Listener.listener_filters', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listener_filters_timeout', full_name='envoy.api.v2.Listener.listener_filters_timeout', index=9,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continue_on_listener_filters_timeout', full_name='envoy.api.v2.Listener.continue_on_listener_filters_timeout', index=10,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transparent', full_name='envoy.api.v2.Listener.transparent', index=11,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='freebind', full_name='envoy.api.v2.Listener.freebind', index=12,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='socket_options', full_name='envoy.api.v2.Listener.socket_options', index=13,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcp_fast_open_queue_length', full_name='envoy.api.v2.Listener.tcp_fast_open_queue_length', index=14,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_direction', full_name='envoy.api.v2.Listener.traffic_direction', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='udp_listener_config', full_name='envoy.api.v2.Listener.udp_listener_config', index=16,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='api_listener', full_name='envoy.api.v2.Listener.api_listener', index=17,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_balance_config', full_name='envoy.api.v2.Listener.connection_balance_config', index=18,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reuse_port', full_name='envoy.api.v2.Listener.reuse_port', index=19,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_log', full_name='envoy.api.v2.Listener.access_log', index=20,
      number=22, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTENER_DEPRECATEDV1, _LISTENER_CONNECTIONBALANCECONFIG, ],
  enum_types=[
    _LISTENER_DRAINTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=493,
  serialized_end=1943,
)

_LISTENER_DEPRECATEDV1.fields_by_name['bind_to_port'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_LISTENER_DEPRECATEDV1.containing_type = _LISTENER
_LISTENER_CONNECTIONBALANCECONFIG_EXACTBALANCE.containing_type = _LISTENER_CONNECTIONBALANCECONFIG
_LISTENER_CONNECTIONBALANCECONFIG.fields_by_name['exact_balance'].message_type = _LISTENER_CONNECTIONBALANCECONFIG_EXACTBALANCE
_LISTENER_CONNECTIONBALANCECONFIG.containing_type = _LISTENER
_LISTENER_CONNECTIONBALANCECONFIG.oneofs_by_name['balance_type'].fields.append(
  _LISTENER_CONNECTIONBALANCECONFIG.fields_by_name['exact_balance'])
_LISTENER_CONNECTIONBALANCECONFIG.fields_by_name['exact_balance'].containing_oneof = _LISTENER_CONNECTIONBALANCECONFIG.oneofs_by_name['balance_type']
_LISTENER.fields_by_name['address'].message_type = envoy_dot_api_dot_v2_dot_core_dot_address__pb2._ADDRESS
_LISTENER.fields_by_name['filter_chains'].message_type = envoy_dot_api_dot_v2_dot_listener_dot_listener__components__pb2._FILTERCHAIN
_LISTENER.fields_by_name['use_original_dst'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_LISTENER.fields_by_name['per_connection_buffer_limit_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_LISTENER.fields_by_name['metadata'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._METADATA
_LISTENER.fields_by_name['deprecated_v1'].message_type = _LISTENER_DEPRECATEDV1
_LISTENER.fields_by_name['drain_type'].enum_type = _LISTENER_DRAINTYPE
_LISTENER.fields_by_name['listener_filters'].message_type = envoy_dot_api_dot_v2_dot_listener_dot_listener__components__pb2._LISTENERFILTER
_LISTENER.fields_by_name['listener_filters_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_LISTENER.fields_by_name['transparent'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_LISTENER.fields_by_name['freebind'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_LISTENER.fields_by_name['socket_options'].message_type = envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2._SOCKETOPTION
_LISTENER.fields_by_name['tcp_fast_open_queue_length'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_LISTENER.fields_by_name['traffic_direction'].enum_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._TRAFFICDIRECTION
_LISTENER.fields_by_name['udp_listener_config'].message_type = envoy_dot_api_dot_v2_dot_listener_dot_udp__listener__config__pb2._UDPLISTENERCONFIG
_LISTENER.fields_by_name['api_listener'].message_type = envoy_dot_config_dot_listener_dot_v2_dot_api__listener__pb2._APILISTENER
_LISTENER.fields_by_name['connection_balance_config'].message_type = _LISTENER_CONNECTIONBALANCECONFIG
_LISTENER.fields_by_name['access_log'].message_type = envoy_dot_config_dot_filter_dot_accesslog_dot_v2_dot_accesslog__pb2._ACCESSLOG
_LISTENER_DRAINTYPE.containing_type = _LISTENER
DESCRIPTOR.message_types_by_name['Listener'] = _LISTENER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Listener = _reflection.GeneratedProtocolMessageType('Listener', (_message.Message,), {

  'DeprecatedV1' : _reflection.GeneratedProtocolMessageType('DeprecatedV1', (_message.Message,), {
    'DESCRIPTOR' : _LISTENER_DEPRECATEDV1,
    '__module__' : 'envoy.api.v2.listener_pb2'
    # @@protoc_insertion_point(class_scope:envoy.api.v2.Listener.DeprecatedV1)
    })
  ,

  'ConnectionBalanceConfig' : _reflection.GeneratedProtocolMessageType('ConnectionBalanceConfig', (_message.Message,), {

    'ExactBalance' : _reflection.GeneratedProtocolMessageType('ExactBalance', (_message.Message,), {
      'DESCRIPTOR' : _LISTENER_CONNECTIONBALANCECONFIG_EXACTBALANCE,
      '__module__' : 'envoy.api.v2.listener_pb2'
      # @@protoc_insertion_point(class_scope:envoy.api.v2.Listener.ConnectionBalanceConfig.ExactBalance)
      })
    ,
    'DESCRIPTOR' : _LISTENER_CONNECTIONBALANCECONFIG,
    '__module__' : 'envoy.api.v2.listener_pb2'
    # @@protoc_insertion_point(class_scope:envoy.api.v2.Listener.ConnectionBalanceConfig)
    })
  ,
  'DESCRIPTOR' : _LISTENER,
  '__module__' : 'envoy.api.v2.listener_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.Listener)
  })
_sym_db.RegisterMessage(Listener)
_sym_db.RegisterMessage(Listener.DeprecatedV1)
_sym_db.RegisterMessage(Listener.ConnectionBalanceConfig)
_sym_db.RegisterMessage(Listener.ConnectionBalanceConfig.ExactBalance)


DESCRIPTOR._options = None
_LISTENER_CONNECTIONBALANCECONFIG.oneofs_by_name['balance_type']._options = None
_LISTENER.fields_by_name['address']._options = None
_LISTENER.fields_by_name['use_original_dst']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v2alpha/clusters.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.admin.v2alpha import metrics_pb2 as envoy_dot_admin_dot_v2alpha_dot_metrics__pb2
from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import health_check_pb2 as envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2
from envoy.type import percent_pb2 as envoy_dot_type_dot_percent__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/admin/v2alpha/clusters.proto',
  package='envoy.admin.v2alpha',
  syntax='proto3',
  serialized_options=b'\n!io.envoyproxy.envoy.admin.v2alphaB\rClustersProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"envoy/admin/v2alpha/clusters.proto\x12\x13\x65nvoy.admin.v2alpha\x1a!envoy/admin/v2alpha/metrics.proto\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a$envoy/api/v2/core/health_check.proto\x1a\x18\x65nvoy/type/percent.proto\x1a\x1dudpa/annotations/status.proto\"H\n\x08\x43lusters\x12<\n\x10\x63luster_statuses\x18\x01 \x03(\x0b\x32\".envoy.admin.v2alpha.ClusterStatus\"\xf5\x01\n\rClusterStatus\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\radded_via_api\x18\x02 \x01(\x08\x12<\n\x1fsuccess_rate_ejection_threshold\x18\x03 \x01(\x0b\x32\x13.envoy.type.Percent\x12\x36\n\rhost_statuses\x18\x04 \x03(\x0b\x32\x1f.envoy.admin.v2alpha.HostStatus\x12I\n,local_origin_success_rate_ejection_threshold\x18\x05 \x01(\x0b\x32\x13.envoy.type.Percent\"\xef\x02\n\nHostStatus\x12+\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12\x30\n\x05stats\x18\x02 \x03(\x0b\x32!.envoy.admin.v2alpha.SimpleMetric\x12<\n\rhealth_status\x18\x03 \x01(\x0b\x32%.envoy.admin.v2alpha.HostHealthStatus\x12)\n\x0csuccess_rate\x18\x04 \x01(\x0b\x32\x13.envoy.type.Percent\x12\x0e\n\x06weight\x18\x05 \x01(\r\x12\x10\n\x08hostname\x18\x06 \x01(\t\x12\x10\n\x08priority\x18\x07 \x01(\r\x12\x36\n\x19local_origin_success_rate\x18\x08 \x01(\x0b\x32\x13.envoy.type.Percent\x12-\n\x08locality\x18\t \x01(\x0b\x32\x1b.envoy.api.v2.core.Locality\"\xf2\x01\n\x10HostHealthStatus\x12\"\n\x1a\x66\x61iled_active_health_check\x18\x01 \x01(\x08\x12\x1c\n\x14\x66\x61iled_outlier_check\x18\x02 \x01(\x08\x12$\n\x1c\x66\x61iled_active_degraded_check\x18\x04 \x01(\x08\x12\x1f\n\x17pending_dynamic_removal\x18\x05 \x01(\x08\x12\x19\n\x11pending_active_hc\x18\x06 \x01(\x08\x12:\n\x11\x65\x64s_health_status\x18\x03 \x01(\x0e\x32\x1f.envoy.api.v2.core.HealthStatusB<\n!io.envoyproxy.envoy.admin.v2alphaB\rClustersProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_admin_dot_v2alpha_dot_metrics__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_address__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2.DESCRIPTOR,envoy_dot_type_dot_percent__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_CLUSTERS = _descriptor.Descriptor(
  name='Clusters',
  full_name='envoy.admin.v2alpha.Clusters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_statuses', full_name='envoy.admin.v2alpha.Clusters.cluster_statuses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=324,
)


_CLUSTERSTATUS = _descriptor.Descriptor(
  name='ClusterStatus',
  full_name='envoy.admin.v2alpha.ClusterStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.admin.v2alpha.ClusterStatus.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='added_via_api', full_name='envoy.admin.v2alpha.ClusterStatus.added_via_api', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success_rate_ejection_threshold', full_name='envoy.admin.v2alpha.ClusterStatus.success_rate_ejection_threshold', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_statuses', full_name='envoy.admin.v2alpha.ClusterStatus.host_statuses', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_origin_success_rate_ejection_threshold', full_name='envoy.admin.v2alpha.ClusterStatus.local_origin_success_rate_ejection_threshold', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=327,
  serialized_end=572,
)


_HOSTSTATUS = _descriptor.Descriptor(
  name='HostStatus',
  full_name='envoy.admin.v2alpha.HostStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='envoy.admin.v2alpha.HostStatus.address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats', full_name='envoy.admin.v2alpha.HostStatus.stats', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health_status', full_name='envoy.admin.v2alpha.HostStatus.health_status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success_rate', full_name='envoy.admin.v2alpha.HostStatus.success_rate', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight', full_name='envoy.admin.v2alpha.HostStatus.weight', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='envoy.admin.v2alpha.HostStatus.hostname', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='envoy.admin.v2alpha.HostStatus.priority', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_origin_success_rate', full_name='envoy.admin.v2alpha.HostStatus.local_origin_success_rate', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locality', full_name='envoy.admin.v2alpha.HostStatus.locality', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=942,
)


_HOSTHEALTHSTATUS = _descriptor.Descriptor(
  name='HostHealthStatus',
  full_name='envoy.admin.v2alpha.HostHealthStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='failed_active_health_check', full_name='envoy.admin.v2alpha.HostHealthStatus.failed_active_health_check', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failed_outlier_check', full_name='envoy.admin.v2alpha.HostHealthStatus.failed_outlier_check', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failed_active_degraded_check', full_name='envoy.admin.v2alpha.HostHealthStatus.failed_active_degraded_check', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending_dynamic_removal', full_name='envoy.admin.v2alpha.HostHealthStatus.pending_dynamic_removal', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending_active_hc', full_name='envoy.admin.v2alpha.HostHealthStatus.pending_active_hc', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eds_health_status', full_name='envoy.admin.v2alpha.HostHealthStatus.eds_health_status', index=5,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=945,
  serialized_end=1187,
)

_CLUSTERS.fields_by_name['cluster_statuses'].message_type = _CLUSTERSTATUS
_CLUSTERSTATUS.fields_by_name['success_rate_ejection_threshold'].message_type = envoy_dot_type_dot_percent__pb2._PERCENT
_CLUSTERSTATUS.fields_by_name['host_statuses'].message_type = _HOSTSTATUS
_CLUSTERSTATUS.fields_by_name['local_origin_success_rate_ejection_threshold'].message_type = envoy_dot_type_dot_percent__pb2._PERCENT
_HOSTSTATUS.fields_by_name['address'].message_type = envoy_dot_api_dot_v2_dot_core_dot_address__pb2._ADDRESS
_HOSTSTATUS.fields_by_name['stats'].message_type = envoy_dot_admin_dot_v2alpha_dot_metrics__pb2._SIMPLEMETRIC
_HOSTSTATUS.fields_by_name['health_status'].message_type = _HOSTHEALTHSTATUS
_HOSTSTATUS.fields_by_name['success_rate'].message_type = envoy_dot_type_dot_percent__pb2._PERCENT
_HOSTSTATUS.fields_by_name['local_origin_success_rate'].message_type = envoy_dot_type_dot_percent__pb2._PERCENT
_HOSTSTATUS.fields_by_name['locality'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._LOCALITY
_HOSTHEALTHSTATUS.fields_by_name['eds_health_status'].enum_type = envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2._HEALTHSTATUS
DESCRIPTOR.message_types_by_name['Clusters'] = _CLUSTERS
DESCRIPTOR.message_types_by_name['ClusterStatus'] = _CLUSTERSTATUS
DESCRIPTOR.message_types_by_name['HostStatus'] = _HOSTSTATUS
DESCRIPTOR.message_types_by_name['HostHealthStatus'] = _HOSTHEALTHSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Clusters = _reflection.GeneratedProtocolMessageType('Clusters', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERS,
  '__module__' : 'envoy.admin.v2alpha.clusters_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.Clusters)
  })
_sym_db.RegisterMessage(Clusters)

ClusterStatus = _reflection.GeneratedProtocolMessageType('ClusterStatus', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERSTATUS,
  '__module__' : 'envoy.admin.v2alpha.clusters_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ClusterStatus)
  })
_sym_db.RegisterMessage(ClusterStatus)

HostStatus = _reflection.GeneratedProtocolMessageType('HostStatus', (_message.Message,), {
  'DESCRIPTOR' : _HOSTSTATUS,
  '__module__' : 'envoy.admin.v2alpha.clusters_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.HostStatus)
  })
_sym_db.RegisterMessage(HostStatus)

HostHealthStatus = _reflection.GeneratedProtocolMessageType('HostHealthStatus', (_message.Message,), {
  'DESCRIPTOR' : _HOSTHEALTHSTATUS,
  '__module__' : 'envoy.admin.v2alpha.clusters_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.HostHealthStatus)
  })
_sym_db.RegisterMessage(HostHealthStatus)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



#! /usr/bin/env python3
# Copyright 2021 The gRPC Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""A PyPI package for xDS protos generated Python code."""

import sys
import os
import setuptools
import pkg_resources

from grpc_tools import protoc

# We might not want to compile all the protos
EXCLUDE_PROTO_PACKAGES_LIST = [
    # Requires extra dependency to Prometheus protos
    'envoy/service/metrics/v2',
    'envoy/service/metrics/v3',
    'envoy/service/metrics/v4alpha',
]

# Compute the pathes
WORK_DIR = os.path.dirname(os.path.abspath(__file__))
GRPC_ROOT = os.path.abspath(os.path.join(WORK_DIR, '..', '..', '..', '..'))
XDS_PROTO_ROOT = os.path.join(GRPC_ROOT, 'third_party', 'envoy-api')
UDPA_PROTO_ROOT = os.path.join(GRPC_ROOT, 'third_party', 'udpa')
GOOGLEAPIS_ROOT = os.path.join(GRPC_ROOT, 'third_party', 'googleapis')
VALIDATE_ROOT = os.path.join(GRPC_ROOT, 'third_party', 'protoc-gen-validate')
OPENCENSUS_PROTO_ROOT = os.path.join(GRPC_ROOT, 'third_party',
                                     'opencensus-proto', 'src')
WELL_KNOWN_PROTOS_INCLUDE = pkg_resources.resource_filename(
    'grpc_tools', '_proto')
OUTPUT_PATH = WORK_DIR

# Prepare the test file generation
TEST_FILE_NAME = 'generated_file_import_test.py'
TEST_IMPORTS = []


def add_test_import(proto_package_path: str,
                    file_name: str,
                    service: bool = False):
    TEST_IMPORTS.append("from %s import %s\n" % (proto_package_path.replace(
        '/', '.'), file_name.replace('.proto', '_pb2')))
    if service:
        TEST_IMPORTS.append("from %s import %s\n" % (proto_package_path.replace(
            '/', '.'), file_name.replace('.proto', '_pb2_grpc')))


# Prepare Protoc command
COMPILE_PROTO_ONLY = [
    'grpc_tools.protoc',
    '--proto_path={}'.format(XDS_PROTO_ROOT),
    '--proto_path={}'.format(UDPA_PROTO_ROOT),
    '--proto_path={}'.format(GOOGLEAPIS_ROOT),
    '--proto_path={}'.format(VALIDATE_ROOT),
    '--proto_path={}'.format(WELL_KNOWN_PROTOS_INCLUDE),
    '--proto_path={}'.format(OPENCENSUS_PROTO_ROOT),
    '--python_out={}'.format(OUTPUT_PATH),
]
COMPILE_BOTH = COMPILE_PROTO_ONLY + ['--grpc_python_out={}'.format(OUTPUT_PATH)]


# Compile xDS protos
def has_grpc_service(proto_package_path: str) -> bool:
    return proto_package_path.startswith('envoy/service')


def compile_protos(proto_root: str, sub_dir: str = '.') -> None:
    for root, _, files in os.walk(os.path.join(proto_root, sub_dir)):
        proto_package_path = os.path.relpath(root, proto_root)
        if proto_package_path in EXCLUDE_PROTO_PACKAGES_LIST:
            print(f'Skipping package {proto_package_path}')
            continue
        for file_name in files:
            if file_name.endswith('.proto'):
                # Compile proto
                if has_grpc_service(proto_package_path):
                    return_code = protoc.main(COMPILE_BOTH +
                                              [os.path.join(root, file_name)])
                    add_test_import(proto_package_path, file_name, service=True)
                else:
                    return_code = protoc.main(COMPILE_PROTO_ONLY +
                                              [os.path.join(root, file_name)])
                    add_test_import(proto_package_path,
                                    file_name,
                                    service=False)
                if return_code != 0:
                    raise Exception('error: {} failed'.format(COMPILE_BOTH))


compile_protos(XDS_PROTO_ROOT)
compile_protos(UDPA_PROTO_ROOT)
# We don't want to compile the entire GCP surface API, just the essential ones
compile_protos(GOOGLEAPIS_ROOT, os.path.join('google', 'api'))
compile_protos(GOOGLEAPIS_ROOT, os.path.join('google', 'rpc'))
compile_protos(GOOGLEAPIS_ROOT, os.path.join('google', 'longrunning'))
compile_protos(GOOGLEAPIS_ROOT, os.path.join('google', 'logging'))
compile_protos(GOOGLEAPIS_ROOT, os.path.join('google', 'type'))
compile_protos(VALIDATE_ROOT, 'validate')
compile_protos(OPENCENSUS_PROTO_ROOT)


# Generate __init__.py files for all modules
def create_init_file(path: str) -> None:
    f = open(os.path.join(path, "__init__.py"), 'w')
    f.close()


create_init_file(WORK_DIR)
for proto_root_module in [
        'envoy', 'google', 'opencensus', 'udpa', 'validate', 'xds'
]:
    for root, _, _ in os.walk(os.path.join(WORK_DIR, proto_root_module)):
        package_path = os.path.relpath(root, WORK_DIR)
        if package_path == "google":
            # Google packages are namespace packages. We don't want to create a
            # package named "google", which will create many trouble down the
            # line.
            continue
        create_init_file(root)

# Generate test file
with open(os.path.join(WORK_DIR, TEST_FILE_NAME), 'w') as f:
    f.writelines(TEST_IMPORTS)

# Use setuptools to build Python package
with open(os.path.join(WORK_DIR, 'README.rst'), 'r') as f:
    LONG_DESCRIPTION = f.read()
PACKAGES = setuptools.find_packages(where=".", exclude=[
    TEST_FILE_NAME
]) + setuptools.find_namespace_packages(include=['google.*'])
CLASSIFIERS = [
    'Development Status :: 3 - Alpha',
    'Programming Language :: Python',
    'Programming Language :: Python :: 2',
    'Programming Language :: Python :: 3',
    'License :: OSI Approved :: Apache Software License',
]
INSTALL_REQUIRES = [
    'grpcio-tools',
    'grpcio',
    'protobuf',
]
SETUP_REQUIRES = INSTALL_REQUIRES
setuptools.setup(
    name='xds-protos',
    version='0.0.3',
    packages=setuptools.find_packages(where=".", exclude=[TEST_FILE_NAME]),
    description='Generated Python code from envoyproxy/data-plane-api',
    long_description_content_type='text/x-rst',
    long_description=LONG_DESCRIPTION,
    author='The gRPC Authors',
    author_email='grpc-io@googlegroups.com',
    url='https://grpc.io',
    license='Apache License 2.0',
    install_requires=INSTALL_REQUIRES,
    setup_requires=SETUP_REQUIRES,
    classifiers=CLASSIFIERS)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v2alpha/tap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.tap.v2alpha import common_pb2 as envoy_dot_service_dot_tap_dot_v2alpha_dot_common__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/admin/v2alpha/tap.proto',
  package='envoy.admin.v2alpha',
  syntax='proto3',
  serialized_options=b'\n!io.envoyproxy.envoy.admin.v2alphaB\010TapProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1d\x65nvoy/admin/v2alpha/tap.proto\x12\x13\x65nvoy.admin.v2alpha\x1a&envoy/service/tap/v2alpha/common.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"l\n\nTapRequest\x12\x1a\n\tconfig_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x42\n\ntap_config\x18\x02 \x01(\x0b\x32$.envoy.service.tap.v2alpha.TapConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42\x37\n!io.envoyproxy.envoy.admin.v2alphaB\x08TapProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_service_dot_tap_dot_v2alpha_dot_common__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_TAPREQUEST = _descriptor.Descriptor(
  name='TapRequest',
  full_name='envoy.admin.v2alpha.TapRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_id', full_name='envoy.admin.v2alpha.TapRequest.config_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tap_config', full_name='envoy.admin.v2alpha.TapRequest.tap_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=150,
  serialized_end=258,
)

_TAPREQUEST.fields_by_name['tap_config'].message_type = envoy_dot_service_dot_tap_dot_v2alpha_dot_common__pb2._TAPCONFIG
DESCRIPTOR.message_types_by_name['TapRequest'] = _TAPREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TapRequest = _reflection.GeneratedProtocolMessageType('TapRequest', (_message.Message,), {
  'DESCRIPTOR' : _TAPREQUEST,
  '__module__' : 'envoy.admin.v2alpha.tap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.TapRequest)
  })
_sym_db.RegisterMessage(TapRequest)


DESCRIPTOR._options = None
_TAPREQUEST.fields_by_name['config_id']._options = None
_TAPREQUEST.fields_by_name['tap_config']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/tap/v2alpha/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/data/tap/v2alpha/common.proto',
  package='envoy.data.tap.v2alpha',
  syntax='proto3',
  serialized_options=b'\n$io.envoyproxy.envoy.data.tap.v2alphaB\013CommonProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#envoy/data/tap/v2alpha/common.proto\x12\x16\x65nvoy.data.tap.v2alpha\x1a\x1dudpa/annotations/status.proto\"O\n\x04\x42ody\x12\x12\n\x08\x61s_bytes\x18\x01 \x01(\x0cH\x00\x12\x13\n\tas_string\x18\x02 \x01(\tH\x00\x12\x11\n\ttruncated\x18\x03 \x01(\x08\x42\x0b\n\tbody_typeB=\n$io.envoyproxy.envoy.data.tap.v2alphaB\x0b\x43ommonProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_BODY = _descriptor.Descriptor(
  name='Body',
  full_name='envoy.data.tap.v2alpha.Body',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='as_bytes', full_name='envoy.data.tap.v2alpha.Body.as_bytes', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='as_string', full_name='envoy.data.tap.v2alpha.Body.as_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='truncated', full_name='envoy.data.tap.v2alpha.Body.truncated', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='body_type', full_name='envoy.data.tap.v2alpha.Body.body_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=94,
  serialized_end=173,
)

_BODY.oneofs_by_name['body_type'].fields.append(
  _BODY.fields_by_name['as_bytes'])
_BODY.fields_by_name['as_bytes'].containing_oneof = _BODY.oneofs_by_name['body_type']
_BODY.oneofs_by_name['body_type'].fields.append(
  _BODY.fields_by_name['as_string'])
_BODY.fields_by_name['as_string'].containing_oneof = _BODY.oneofs_by_name['body_type']
DESCRIPTOR.message_types_by_name['Body'] = _BODY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Body = _reflection.GeneratedProtocolMessageType('Body', (_message.Message,), {
  'DESCRIPTOR' : _BODY,
  '__module__' : 'envoy.data.tap.v2alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.tap.v2alpha.Body)
  })
_sym_db.RegisterMessage(Body)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
